@@ -203,7 +203,7 @@ class KnockPY(object):
         subdomains = []
 
         print("Searching binary_edge")
-        binary_subdomains += await self.binary_edge()
+        binary_subdomains == await self.binary_edge()
         
         if binary_subdomains:
             subdomains += binary_subdomains
